==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/CadToolMatrix/ts/CadToolMatrix_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>CadToolMatrix</name>
    <message>
        <location filename="../CadToolMatrix.js" line="+366"/>
        <source>Expand all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Collapse all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>List View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Icon View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Widgets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+48"/>
        <source>Tool Matrix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Pixel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>List view</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolMatrixWidget</name>
    <message>
        <location filename="../CadToolMatrix.ui" line="+37"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/CadToolMatrix/ts/CadToolMatrix_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>CadToolMatrix</name>
    <message>
        <location filename="../CadToolMatrix.js" line="+373"/>
        <source>Expand all</source>
        <translation>全て広げる</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Collapse all</source>
        <translation>すべてたたむ</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>List View</source>
        <translation>リストビュー</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Icon View</source>
        <translation>アイコンビュー</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Widgets</source>
        <translation>ウィジェット</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+48"/>
        <source>Tool Matrix</source>
        <translation>ツールマトリクス</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Icon Size:</source>
        <translation>アイコンのサイズ:</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Pixel</source>
        <translation>ピクセル</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>List view</source>
        <translation>リストビュー</translation>
    </message>
</context>
<context>
    <name>ToolMatrixWidget</name>
    <message>
        <location filename="../CadToolMatrix.ui" line="+37"/>
        <source>Filter</source>
        <translation>フィルター</translation>
    </message>
</context>
</TS>
